==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/nullcheck/LocalRefVarsAnalysisWrapper.h <==
// public class soot.jimple.toolkits.annotation.nullcheck.LocalRefVarsAnalysisWrapper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b7556d0d5f61527a soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper_H_
#define _JC_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object;
struct _jc_soot_toolkits_graph_CompleteUnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object;

typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct {
	jboolean	computeChecks;
	jboolean	discardKTop;
};
extern _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$_init$3c973f2f1fb3db19(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_soot_toolkits_graph_CompleteUnitGraph$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$buildList$682c3d50a46988b9(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getListsOfVarsAfterBranch$ba1892c697b3545e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsAfterFall$6fb8e30efbf4f0a5(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsBefore$7d1b2ed49343490a(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsDontNeedCheck$a1f28ec9a4837d3c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsNeedCheck$f34718a43ddd302a(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$buildList$682c3d50a46988b9;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getListsOfVarsAfterBranch$ba1892c697b3545e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsAfterFall$6fb8e30efbf4f0a5;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsBefore$7d1b2ed49343490a;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsDontNeedCheck$a1f28ec9a4837d3c;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsNeedCheck$f34718a43ddd302a;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods {
	struct _jc_object	*(*buildList$682c3d50a46988b9)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
	struct _jc_object	*(*getListsOfVarsAfterBranch$ba1892c697b3545e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
	struct _jc_object	*(*getVarsAfterFall$6fb8e30efbf4f0a5)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
	struct _jc_object	*(*getVarsBefore$7d1b2ed49343490a)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
	struct _jc_object	*(*getVarsDontNeedCheck$a1f28ec9a4837d3c)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
	struct _jc_object	*(*getVarsNeedCheck$f34718a43ddd302a)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods	soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs {
	struct _jc_object	*unitToVarsBefore;
	struct _jc_object	*unitToVarsAfterFall;
	struct _jc_object	*unitToListsOfVarsAfterBranches;
	struct _jc_object	*unitToVarsNeedCheck;
	struct _jc_object	*unitToVarsDontNeedCheck;
	struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object	*analysis;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs {
    _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs	soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs	soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object {
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/nullcheck/LocalRefVarsAnalysisWrapper.h <==
// public class soot.jimple.toolkits.annotation.nullcheck.LocalRefVarsAnalysisWrapper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b7556d0d5f61527a soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper_H_
#define _JC_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object;
struct _jc_soot_toolkits_graph_CompleteUnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object;

typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct {
	jboolean	computeChecks;
	jboolean	discardKTop;
};
extern _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$fields_struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$_init$3c973f2f1fb3db19(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_soot_toolkits_graph_CompleteUnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$buildList$682c3d50a46988b9(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getListsOfVarsAfterBranch$ba1892c697b3545e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsAfterFall$6fb8e30efbf4f0a5(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsBefore$7d1b2ed49343490a(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsDontNeedCheck$a1f28ec9a4837d3c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method$getVarsNeedCheck$f34718a43ddd302a(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$buildList$682c3d50a46988b9;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getListsOfVarsAfterBranch$ba1892c697b3545e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsAfterFall$6fb8e30efbf4f0a5;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsBefore$7d1b2ed49343490a;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsDontNeedCheck$a1f28ec9a4837d3c;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$method_info$getVarsNeedCheck$f34718a43ddd302a;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods {
	struct _jc_object	*(*buildList$682c3d50a46988b9)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getListsOfVarsAfterBranch$ba1892c697b3545e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getVarsAfterFall$6fb8e30efbf4f0a5)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getVarsBefore$7d1b2ed49343490a)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getVarsDontNeedCheck$a1f28ec9a4837d3c)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getVarsNeedCheck$f34718a43ddd302a)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vmethods	soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs {
	struct _jc_object	*unitToVarsBefore;
	struct _jc_object	*unitToVarsAfterFall;
	struct _jc_object	*unitToListsOfVarsAfterBranches;
	struct _jc_object	*unitToVarsNeedCheck;
	struct _jc_object	*unitToVarsDontNeedCheck;
	struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object	*analysis;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs {
    _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_refs	soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$sub_nonrefs	soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$object {
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$vtype _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_nullcheck_LocalRefVarsAnalysisWrapper_H_ */
